#!/usr/bin/env python
# coding: utf-8

"""
    %prog [options] REV1 REV2

Print the list of issues solved between two revisions: ]REV1, REV2]
REV1 is excluded, REV2 is included.

"""

import os
import re
from optparse import OptionParser
from subprocess import Popen, PIPE

from aslint.logger import logger, setlevel
from aslint.i18n import _
from hgaster.ext_utils import get_issues_from_descr


def get_log(rev1, rev2):
    """Read the issues numbers from 'fname'"""
    cmd = ['hg', 'log', '-r', '%s::%s - %s' % (rev1, rev2, rev1),
           '--template', "\nRevision {rev}:{node}\n{desc}\n"]
    out = Popen(cmd, stdout=PIPE).communicate()[0]
    return out

if __name__ == '__main__':
    # command arguments parser
    parser = OptionParser(usage=__doc__)
    parser.add_option('-g', '--debug', action='callback', callback=setlevel,
                      help="add debug informations")
    parser.add_option('--rex',
                      dest='filter', action='store_const', const='rex',
                      help="return the issues solved in REX")
    parser.add_option('--bitbucket',
                      dest='filter',  action='store_const', const='bitbucket',
                      help="return the issues solved in Bitbucket")
    opts, args = parser.parse_args()
    if len(args) != 2:
        parser.error("exactly two arguments are required")
    text = get_log(*args)
    logger.debug(text)
    issues = get_issues_from_descr(text, filter=opts.filter)
    print '\n'.join(map(str, issues))
