#!/usr/bin/env python
# coding: utf-8

"""
    %prog [options] [repository_path]

Show the last current tag and compute the next one
"""

import os.path as osp
import re
from optparse import OptionParser
from functools import partial
import time
from subprocess import Popen, PIPE

from aslint.logger import logger, setlevel

FMTTAG = '([0-9]+)\.([0-9]+)\.([0-9]+)'


def next_tag(repo, branch='.', verbose=False):
    """Return the tag of the next minor version"""
    cmd = ['hg', 'log', '-R', repo,
           '--rev', 'last(tag() and branch(%s))' % branch,
           '--template', "{tags}\n"]
    tag = Popen(cmd, stdout=PIPE).communicate()[0].strip()
    if not tag:
        raise ValueError("No tag found in this branch. This may happen on a "
                         "newly created branch. Define OLD and TAG yourself!")
    mat = re.search(FMTTAG, tag)
    if not mat:
        raise ValueError('invalid tag: %r' % tag)
    tag = re.findall(FMTTAG, tag)
    branch, major, minor = tag[0]
    old = '%s.%s.%s' % (branch, major, minor)
    ntag = '%s.%s.%s' % (branch, major, int(minor) + 1)
    if verbose:
        logger.info('OLD=%s', old)
        logger.info('TAG=%s', ntag)
    return ntag


if __name__ == '__main__':
    # command arguments parser
    parser = OptionParser(usage=__doc__)
    parser.add_option('-g', '--debug', action='callback', callback=setlevel,
                      help="add debug informations")
    opts, args = parser.parse_args()
    repo = '.'
    if len(args) > 0:
        repo = args[0]
    if len(args) > 1:
        parser.error("at most one argument is required")
    next_tag(repo, verbose=True)
