# coding=utf-8

"""Some basic utilities"""
# no import of aslint here

import locale
import os
import os.path as osp
import UserDict


def force_list(obj):
    """Force to return a list"""
    if type(obj) not in (list, tuple):
        obj = [obj, ]
    return obj


def get_absolute_path(path):
    """Return the absolute path of `path`, eventually by following the
    symbolic links."""
    if osp.islink(path):
        path = osp.realpath(path)
    res = osp.normpath(osp.abspath(path))
    return res


def get_absolute_dirname(path):
    """Return the absolute directory name of `path`, eventually by following
    the symbolic links."""
    res = osp.normpath(osp.join(get_absolute_path(path), os.pardir))
    return res

_encoding = None


def get_encoding():
    """Return local encoding"""
    global _encoding
    if _encoding is None:
        try:
            _encoding = locale.getpreferredencoding() or 'ascii'
        except locale.Error:
            _encoding = 'ascii'
    return _encoding

# http://stackoverflow.com/questions/898669/
#   how-can-i-detect-if-a-file-is-binary-non-text-in-python


def is_binary(fname):
    """Tell if a file appears to be binary (containing a NULL byte)
    Note: UTF-16 files are reported as binary."""
    fobj = open(fname, 'rb')
    try:
        for block in fobj:
            if '\0' in block:
                return True
    finally:
        fobj.close()
    return False


class NeverFailedDict(UserDict.IterableUserDict):
    """A dict that never raise KeyError
    Return a new NeverFailedDict if the key does not exist."""

    def __getitem__(self, key):
        """x.__getitem__(y) <==> x[y]"""
        try:
            return UserDict.IterableUserDict.__getitem__(self, key)
        except KeyError:
            return NeverFailedDict()


def on_calibre(vers=""):
    """Tell if the OS has a Calibre installation"""
    name = "Calibre {0}".format(vers)
    return name.strip() in open('/etc/issue', 'rb').read()
