# coding=utf-8

"""extensions added for the Code_Aster project"""

# demandimport causes problems when activated
# with python < 2.7 at calls of skip decorators
try:
    from mercurial import demandimport
    demandimport.disable()
except:
    pass

from . import ascommands

cmdtable = ascommands.cmdtable

testedwith = "2.2 2.3 2.4 2.5 2.6 3.1 3.7"
buglink = "https://bitbucket.org/code_aster/codeaster-src/issues"


def uisetup(ui):
    """Setup the aster extensions"""
    try:
        from mercurial import util
        from distutils.version import StrictVersion
        vers = util.version()
        try:
            svers = StrictVersion(vers)
        except ValueError:
            import re
            svers = StrictVersion(re.search('^([0-9\.]+)', vers).group(1))
        if svers < StrictVersion('2.2'):
            raise util.Abort("'aster' extension requires Mercurial 2.2 or "
                             "later, 2.5 or later recommended")
    except (ImportError, AttributeError):
        ui.warn("can not check Mercurial version, version 2.5 or "
                "later recommended\n")
    # check aslint availability
    try:
        import aslint as dummy
    except ImportError:
        ui.warn("'aslint' package not found.\n"
                "You should run 'install_env' that will tell you how to fill "
                "the PYTHONPATH environment variable.\n")
